@@ -6,11 +6,21 @@ from simple_ddl_parser.utils import remove_par
 
 
 class AfterColumns:
-    def p_expression_partitioned_by(self, p):
-        """expr : expr PARTITIONED BY LP pid RP"""
+    def p_expression_partition_by(self, p):
+        """expr : expr PARTITION BY LP pid RP
+        | expr PARTITION BY ID LP pid RP
+        | expr PARTITION BY pid
+        | expr PARTITION BY ID pid"""
         p[0] = p[1]
         p_list = list(p)
-        p[0]["partitioned_by"] = p_list[-2]
+        _type = None
+        if isinstance(p[4], list):
+            columns = p[4]
+        else:
+            columns = p_list[-2]
+        if isinstance(p[4], str) and p[4].lower() != "(":
+            _type = p[4]
+        p[0]["partition_by"] = {"columns": columns, "type": _type}
 
 
 class Database:
@@ -210,6 +220,8 @@ class Column:
         elif isinstance(p_list[-1], dict):
             if p_list[-1].get("type"):
                 p[0]["type"] += f"{p_list[-1]['type'].strip()}"
+            elif p_list[-1].get("comment"):
+                p[0].update(p_list[-1])
             elif p_list[-1].get("property"):
                 for key, value in p_list[-1]["property"].items():
                     p[0][key] = value
@@ -1101,7 +1113,7 @@ class BaseSQL(
         p[0] = {"primary_key": p_list[-1]}
 
     def p_comment(self, p):
-        """comment : ID STRING"""
+        """comment : COMMENT STRING"""
         p_list = remove_par(list(p))
         p[0] = {"comment": p_list[-1]}
 
